# import numpy
# import pandas

# Configuration variables

api_key = None
api_base = "https://petaldata.app/api"
cache_dir = None

# API Resources

from petaldata.resource import *
from petaldata.resource import abstract
from petaldata.resource import hubspot
from petaldata.resource import stripe
from petaldata.resource.stripe.reports import *


from petaldata.storage import *